'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = traverseImport;

var _babylon = require('babylon');

var babylon = _interopRequireWildcard(_babylon);

var _babelTraverse = require('babel-traverse');

var _babelTraverse2 = _interopRequireDefault(_babelTraverse);

var _babelTypes = require('babel-types');

var types = _interopRequireWildcard(_babelTypes);

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

/* eslint-disable new-cap */

function traverseImport(options, inputSource) {
  var specified = void 0; // Collector import specifiers

  function variableDeclarationMethod(name, value) {
    return types.VariableDeclaration('const', [types.variableDeclarator(types.Identifier(name), types.BooleanLiteral(value))]);
  }

  var platformMap = {
    weex: 'isWeex',
    web: 'isWeb',
    node: 'isNode',
    reactnative: 'isReactNative'
  };

  var ast = babylon.parse(inputSource, {
    sourceType: 'module',
    plugins: ['*']
  });

  (0, _babelTraverse2.default)(ast, {
    enter: function enter() {
      specified = new Array();
    },
    ImportDeclaration: function ImportDeclaration(path) {
      var node = path.node;


      if (node.source.value === options.name) {
        node.specifiers.forEach(function (spec) {
          specified.push({
            local: spec.local.name,
            imported: spec.imported.name
          });
        });

        var hasPlatformSpecified = false;

        specified.forEach(function (spec) {
          if (typeof platformMap[options.platform] !== 'undefined') {
            hasPlatformSpecified = true;
          }
        });

        if (hasPlatformSpecified) {
          specified.forEach(function (specObj) {
            var newNodeInit = specObj.imported === platformMap[options.platform] ? true : false;
            var newNode = variableDeclarationMethod(specObj.imported, newNodeInit);

            path.insertAfter(newNode);

            // Support custom alise import:
            // import { isWeex as iw } from 'universal-env';
            // const isWeex = true;
            // const iw = true;
            if (specObj.imported !== specObj.local) {
              newNode = variableDeclarationMethod(specObj.local, newNodeInit);
              path.insertAfter(newNode);
            }
          });

          path.remove();
        }
      } else {
        if (options.platform) {
          node.source.value = node.source.value + '?platform=' + options.platform;
        }
      }
    }
  });

  return (0, _babelGenerator2.default)(ast, null, inputSource);
};